dm 'clear log';dm 'clear output';
/**--------------------------------------------------------------------**/
/** Programm: ExampleIlleEtVil.sas                                     **/
/**    Project    : sas two-phase package                              **/
/**    Author     : Schill                                             **/
/**    Date       : 2014-03-15                                         **/
/**                                                                    **/
/**    Context    : attributable fractions                             **/
/**    Purpose    : Calculate adjusted attributable fractions          **/
/**    Method     : produce artificial two-phase setup: one stratum,   **/
/**                 phase 1 dataset has two observations               **/
/**    Procs      : --                                                 **/
/**    Include    : %twophase, %af2p                                          **/
/**    Input      : Ille et Vilaine data                               **/
/**    Output     :                                                    **/
/**                                                                    **/
/**    Validation :                                                    **/
/**    Status     :                                                    **/
/**    Doku       : --                                                 **/
/**    Reference  : Breslow & Day, Vol.1, AFDocu.pdf                   **/
/**--------------------------------------------------------------------**/

options nocenter mprint nodate nonumber;
options nodate nonumber nocenter ps=34 ls=116 notes mprint nomlogic  formchar="|----|+|---" ;
%let prgname=ExampleIlleEtVil.sas;
footnote "Prgm: &prgname, &sysdate";

*This is the path, where the two-phase macros are stored;
%let path_tp=%str(d:\ESave\sas-twophase-package\macros);
*include twophase-Macro;
%include "&path_tp.\twophase.sas";

*This is the path, where the attributable risk macro is stored;
%let path_af=%str(d:\ESave\sas-af2phase\macros);
*include attributable fraction-Macro;
%include "&path_af.\af2p.sas";

*libname of input data;
libname in "d:\ESave\sas-af2phase\data";


title;

%macro illeEtVilaine;

     /* Define artificial stratum variable sdum */
     data illev2;set in.ille_et_vilaine;
          sdum=1;
     proc sort;by sdum;
     run;
     /* Produce artificial phase one dataset */
     proc freq data=illev2 noprint;
          tables case/nocol norow nopercent out=illev1;
          weight n;
          by sdum;
     run;
     proc print data=illev1;
     title'Ille et Vilaine Data (phase 1 )';
     run;
     %twophase(folder      =&path_tp,
               path_ph1    =illev1,
               path_ph2    =illev2,
               methods     =ml_em wl s2,
               compare     =1,
               outest      =1,
               caco        =case,
               svar        =sdum,
               counts_ph1  =count,
               weights_ph2 =n,
               regr        =age2 age3 age4 age5 age6 alc2 alc3 alc4 tob2 tob3 tob4,
               s1pr        =0);

     /*
     proc logistic data=illev2 des;
          model caco=age2-age6 alc2-alc4 tob2-tob4;
          weight n;
     run;
     */
     %af2p(pathout=af1,
           regress=age2 age3 age4 age5 age6 alc2 alc3 alc4 tob2 tob3 tob4,
            factor=alc2 alc3 alc4,
            NameF =Alcohol,
            Study =Ille et Vilaine,
           s1pr   =0);
     %af2p(pathout=af2,
           regress=age2 age3 age4 age5 age6 alc2 alc3 alc4 tob2 tob3 tob4,
            factor=tob2 tob3 tob4,
            NameF =Tobacco,
            Study =Ille et Vilaine,
           s1pr   =0);
     %af2p(pathout=af3,
           regress=age2 age3 age4 age5 age6 alc2 alc3 alc4 tob2 tob3 tob4,
            factor=tob2 tob3 tob4 alc2 alc3 alc4,
            NameF =Tobacco+Alcohol,
            Study =Ille et Vilaine,
           s1pr   =0);
     data af;set af1 af2 af3;
     run;
     title 'Attributable fractions in the Ille et Vilaine study';
     proc print data=af label noobs;
          var NameF af Cl_af cu_af;
     run;
%mend;
%IlleEtVilaine;
